Evaluator
=========

.. currentmodule:: pykeen.evaluation

.. autoclass:: Evaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Evaluator.batch_and_slice
      ~Evaluator.evaluate
      ~Evaluator.finalize
      ~Evaluator.get_normalized_name
      ~Evaluator.process_head_scores_
      ~Evaluator.process_tail_scores_

   .. rubric:: Methods Documentation

   .. automethod:: batch_and_slice
   .. automethod:: evaluate
   .. automethod:: finalize
   .. automethod:: get_normalized_name
   .. automethod:: process_head_scores_
   .. automethod:: process_tail_scores_
